@@ -148,6 +148,11 @@ PluginModuleChild::Init(const std::string& aPluginFilename,
 
     GetIPCChannel()->SetAbortOnError(true);
 
+    // Request Windows message deferral behavior on our channel. This
+    // applies to the top level and all sub plugin protocols since they
+    // all share the same channel.
+    GetIPCChannel()->SetChannelFlags(MessageChannel::REQUIRE_DEFERRED_MESSAGE_PROTECTION);
+
 #ifdef XP_WIN
     COMMessageFilter::Initialize(this);
 #endif
